@@ -15,9 +15,16 @@ else
   DEBUG_FLAG=--debug
 fi
 
-echo "initial CHECKERFRAMEWORK=$CHECKERFRAMEWORK"
 export CHECKERFRAMEWORK="${CHECKERFRAMEWORK:-$(pwd -P)}"
 echo "CHECKERFRAMEWORK=$CHECKERFRAMEWORK"
+SCRIPT_DIR="$(cd -- "$(dirname -- "${BASH_SOURCE[0]}")" &> /dev/null && pwd)"
+
+IS_CI="$("$SCRIPT_DIR"/is-ci.sh)"
+export IS_CI
+if [ -n "$IS_CI" ]; then
+  # CircleCI fails, for the Daikon job only, if "-Dorg.gradle.daemon=false" is removed.
+  export GRADLE_OPTS="${GRADLE_OPTS} -Dorg.gradle.daemon=false -Dorg.gradle.console=plain -Xmx4g"
+fi
 
 export SHELLOPTS
 echo "SHELLOPTS=${SHELLOPTS}"
@@ -32,11 +39,11 @@ fi
 echo "JAVA_HOME=${JAVA_HOME}"
 
 # Using `(cd "$CHECKERFRAMEWORK" && ./gradlew getGitScripts -q)` leads to infinite regress.
-GIT_SCRIPTS="$CHECKERFRAMEWORK/checker/bin-devel/.git-scripts"
+GIT_SCRIPTS="${SCRIPT_DIR}/.git-scripts"
 if [ -d "$GIT_SCRIPTS" ]; then
   (cd "$GIT_SCRIPTS" && (git pull -q || true))
 else
-  (cd "$CHECKERFRAMEWORK/checker/bin-devel" \
+  (cd "${SCRIPT_DIR}" \
     && (git clone --depth=1 -q https://github.com/plume-lib/git-scripts.git .git-scripts \
       || (sleep 60 && git clone --depth=1 -q https://github.com/plume-lib/git-scripts.git .git-scripts)))
 fi
@@ -44,20 +51,6 @@ fi
 # Clone the annotated JDK into ../jdk .
 "$GIT_SCRIPTS/git-clone-related" ${DEBUG_FLAG} typetools jdk
 
-AFU="${AFU:-../annotation-tools/annotation-file-utilities}"
-# Don't use `AT=${AFU}/..` which causes a git failure.
-AT=$(dirname "${AFU}")
-
-## Build annotation-tools (Annotation File Utilities)
-"$GIT_SCRIPTS/git-clone-related" ${DEBUG_FLAG} typetools annotation-tools "${AT}"
-if [ ! -d ../annotation-tools ]; then
-  ln -s "${AT}" ../annotation-tools
-fi
-
-echo "Running:  (cd ${AT} && ./.build-without-test.sh)"
-(cd "${AT}" && ./.build-without-test.sh)
-echo "... done: (cd ${AT} && ./.build-without-test.sh)"
-
 ### Commented temporarily because JSpecify build is failing under JDK 17.
 ### (I guess they don't use continuous integration.)
 # ## Build JSpecify, only for the purpose of using its tests.
@@ -78,16 +71,37 @@ echo "... done: (cd ${AT} && ./.build-without-test.sh)"
 #   echo "... done: (cd ../jspecify/ && ./gradlew build)"
 # fi
 
+# Test that the CF, when built with JDK 21, works on other JDKs.
+export ORG_GRADLE_PROJECT_useJdk21Compiler=true
+
+# Set JAVA_HOME to JDK 21 so that Gradle runs using Java 21.
+# Prefer an OS-appropriate default only if JAVA21_HOME is unset and exists.
+if [ -z "${JAVA21_HOME:-}" ]; then
+  if [ "$(uname)" = "Darwin" ]; then
+    CANDIDATE="$(/usr/libexec/java_home -v 21 2> /dev/null || true)"
+    [ -n "$CANDIDATE" ] && export JAVA21_HOME="$CANDIDATE"
+  elif [ -d /usr/lib/jvm/java-21-openjdk-amd64 ]; then
+    export JAVA21_HOME=/usr/lib/jvm/java-21-openjdk-amd64
+  fi
+fi
+# Only override JAVA_HOME if JAVA21_HOME points to a usable JDK.
+if [ -n "${JAVA21_HOME:-}" ] && [ -x "${JAVA21_HOME}/bin/java" ]; then
+  export JAVA_HOME="${JAVA21_HOME}"
+fi
 ## Compile
 
-# Download dependencies, trying a second time if there is a failure.
-# echo "NO_WRITE_VERIFICATION_METADATA=$NO_WRITE_VERIFICATION_METADATA"
-if [ -z "${NO_WRITE_VERIFICATION_METADATA+x}" ]; then
-  (TERM=dumb timeout 300 ./gradlew --write-verification-metadata sha256 help --dry-run --quiet \
-    || (echo "./gradlew --write-verification-metadata sha256 help --dry-run --quiet failed; sleeping before trying again." \
-      && sleep 1m \
-      && echo "Trying again: ./gradlew --write-verification-metadata sha256 help --dry-run --quiet" \
-      && TERM=dumb timeout 300 ./gradlew --write-verification-metadata sha256 help --dry-run --quiet))
+# Download Gradle and dependencies, retrying in case of network problems.
+# Under CircleCI, the `timeout` command seems to hang forever.
+if [ -z "$CIRCLECI" ]; then
+  # echo "NO_WRITE_VERIFICATION_METADATA=$NO_WRITE_VERIFICATION_METADATA"
+  if [ -z "${NO_WRITE_VERIFICATION_METADATA+x}" ]; then
+    # Note that "timeout" is not compatible with shell functions.
+    TERM=dumb ./gradlew --write-verification-metadata sha256 help --dry-run --quiet \
+      || { echo "./gradlew --write-verification-metadata sha256 help --dry-run failed; sleeping before trying again." \
+        && sleep 1m \
+        && echo "Trying again: ./gradlew --write-verification-metadata sha256 help --dry-run" \
+        && TERM=dumb ./gradlew --write-verification-metadata sha256 help --dry-run; }
+  fi
 fi
 
 echo Exiting checker/bin-devel/clone-related.sh in "$(pwd)"
