@@ -10,15 +10,10 @@ export SHELLOPTS
 echo "SHELLOPTS=${SHELLOPTS}"
 
 SCRIPT_DIR="$(cd -- "$(dirname -- "${BASH_SOURCE[0]}")" &> /dev/null && pwd)"
-# Test that the CF, when built with JDK 21, works on other JDKs.
-export ORG_GRADLE_PROJECT_useJdk21Compiler=true
-
-# Run Gradle using Java 21.
-mkdir ~/.gradle && echo "org.gradle.java.home=/usr/lib/jvm/java-21-openjdk-amd64" >> ~/.gradle/gradle.properties
 
 source "$SCRIPT_DIR"/clone-related.sh
 
-./gradlew allTests --console=plain --warning-mode=all
+./gradlew allTests --warning-mode=all
 # Moved example-tests out of all tests because it fails in
-# the release script because the newest maven artifacts are not published yet.
-./gradlew :checker:exampleTests --console=plain --warning-mode=all
+# the release script because the newest Maven artifacts are not published yet.
+./gradlew :checker:exampleTests --warning-mode=all
