@@ -1,6 +1,6 @@
 package org.checkerframework.checker.fenum;
 
-import java.util.SortedSet;
+import java.util.NavigableSet;
 import javax.annotation.processing.SupportedOptions;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.common.subtyping.SubtypingChecker;
@@ -26,7 +26,7 @@ import org.checkerframework.framework.qual.StubFiles;
 public class FenumChecker extends BaseTypeChecker {
 
   @Override
-  public SortedSet<String> getSuppressWarningsPrefixes() {
+  public NavigableSet<String> getSuppressWarningsPrefixes() {
     return SubtypingChecker.getSuppressWarningsPrefixes(
         this.visitor, super.getSuppressWarningsPrefixes());
   }
