@@ -10,8 +10,8 @@ import org.checkerframework.checker.index.Subsequence;
 import org.checkerframework.checker.index.upperbound.OffsetEquation;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.common.basetype.BaseTypeVisitor;
+import org.checkerframework.dataflow.expression.JavaExpressionParseException;
 import org.checkerframework.framework.type.AnnotatedTypeMirror;
-import org.checkerframework.framework.util.JavaExpressionParseUtil;
 import org.plumelib.util.CollectionsPlume;
 
 /** The visitor for the Less Than Checker. */
@@ -42,7 +42,7 @@ public class LessThanVisitor extends BaseTypeVisitor<LessThanAnnotatedTypeFactor
         anm =
             atypeFactory.getAnnotationMirrorFromJavaExpressionString(
                 subSeq.from, varTree, getCurrentPath());
-      } catch (JavaExpressionParseUtil.JavaExpressionParseException e) {
+      } catch (JavaExpressionParseException e) {
         anm = null;
       }
 
