@@ -11,8 +11,8 @@ import org.checkerframework.checker.index.qual.NonNegative;
 import org.checkerframework.checker.index.qual.Positive;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.common.basetype.BaseTypeVisitor;
+import org.checkerframework.dataflow.expression.JavaExpressionParseException;
 import org.checkerframework.framework.type.AnnotatedTypeMirror;
-import org.checkerframework.framework.util.JavaExpressionParseUtil;
 
 /**
  * Implements the actual checks to make sure that array accesses aren't too low. Will issue a
@@ -79,7 +79,7 @@ public class LowerBoundVisitor extends BaseTypeVisitor<LowerBoundAnnotatedTypeFa
         anm =
             atypeFactory.getAnnotationMirrorFromJavaExpressionString(
                 subSeq.from, varTree, getCurrentPath());
-      } catch (JavaExpressionParseUtil.JavaExpressionParseException e) {
+      } catch (JavaExpressionParseException e) {
         anm = null;
       }
       if (anm == null
