@@ -197,7 +197,7 @@ public abstract class InitializationAnnotatedTypeFactory<
   public abstract AnnotationMirror getFieldInvariantAnnotation();
 
   /**
-   * Returns whether or not {@code field} has the invariant annotation.
+   * Returns true if {@code field} has the invariant annotation.
    *
    * <p>This method is a convenience method for {@link
    * #hasFieldInvariantAnnotation(AnnotatedTypeMirror, VariableElement)}.
@@ -207,7 +207,7 @@ public abstract class InitializationAnnotatedTypeFactory<
    * NullnessAnnotatedTypeFactory#hasFieldInvariantAnnotation(VariableTree)} for an example.
    *
    * @param field field that might have invariant annotation
-   * @return whether or not field has the invariant annotation
+   * @return true if field has the invariant annotation
    */
   protected final boolean hasFieldInvariantAnnotation(VariableTree field) {
     AnnotatedTypeMirror type = getAnnotatedType(field);
@@ -216,7 +216,7 @@ public abstract class InitializationAnnotatedTypeFactory<
   }
 
   /**
-   * Returns whether or not {@code type} has the invariant annotation.
+   * Returns true if {@code type} has the invariant annotation.
    *
    * <p>If the {@code type} is a type variable, this method returns true if any possible
    * instantiation of the type parameter could have the invariant annotation. See {@link
@@ -225,7 +225,7 @@ public abstract class InitializationAnnotatedTypeFactory<
    * @param type of field that might have invariant annotation
    * @param fieldElement the field element, which can be used to check annotations on the
    *     declaration
-   * @return whether or not the type has the invariant annotation
+   * @return true if the type has the invariant annotation
    */
   protected abstract boolean hasFieldInvariantAnnotation(
       AnnotatedTypeMirror type, VariableElement fieldElement);
@@ -571,7 +571,7 @@ public abstract class InitializationAnnotatedTypeFactory<
    *
    * @param store a store
    * @param path the current path, used to determine the current class
-   * @param isStatic whether to report static fields or instance fields
+   * @param isStatic if true, report static fields; if false, report instance fields
    * @param receiverAnnotations the annotations on the receiver
    * @return the fields that are not yet initialized in a given store (a pair of lists)
    */
@@ -610,7 +610,7 @@ public abstract class InitializationAnnotatedTypeFactory<
    *
    * @param store a store
    * @param path the current path, used to determine the current class
-   * @param isStatic whether to report static fields or instance fields
+   * @param isStatic if true, report static fields; if false, report instance fields
    * @param receiverAnnotations the annotations on the receiver
    * @return the fields that have the invariant annotation and are not yet initialized in a given
    *     store (a pair of lists)
@@ -649,7 +649,7 @@ public abstract class InitializationAnnotatedTypeFactory<
     return initializedFields;
   }
 
-  /** Returns whether the field {@code f} is unused, given the annotations on the receiver. */
+  /** Returns true if the field {@code f} is unused, given the annotations on the receiver. */
   private boolean isUnused(
       VariableTree field, Collection<? extends AnnotationMirror> receiverAnnos) {
     if (receiverAnnos.isEmpty()) {
@@ -674,7 +674,7 @@ public abstract class InitializationAnnotatedTypeFactory<
   }
 
   /**
-   * Return true if the type is initialized with respect to the given frame -- that is, all of the
+   * Returns true if the type is initialized with respect to the given frame -- that is, all of the
    * fields of the frame are initialized.
    *
    * @param type the type whose initialization type qualifiers to check
@@ -800,10 +800,8 @@ public abstract class InitializationAnnotatedTypeFactory<
         if (!TreeUtils.isStandaloneExpression(a)) {
           continue;
         }
-        boolean oldShouldCache = shouldCache;
-        shouldCache = false;
+
         AnnotatedTypeMirror t = getAnnotatedType(a);
-        shouldCache = oldShouldCache;
         allInitialized &= (isInitialized(t) || isFbcBottom(t));
       }
       if (!allInitialized) {
