@@ -1,12 +1,11 @@
 package org.checkerframework.checker.lock;
 
-import java.util.Set;
-import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.type.TypeMirror;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.framework.flow.CFAbstractAnalysis;
 import org.checkerframework.framework.flow.CFStore;
 import org.checkerframework.framework.flow.CFValue;
+import org.checkerframework.javacutil.AnnotationMirrorSet;
 
 /**
  * The analysis class for the lock type system.
@@ -42,7 +41,7 @@ public class LockAnalysis extends CFAbstractAnalysis<CFValue, LockStore, LockTra
   }
 
   @Override
-  public CFValue createAbstractValue(Set<AnnotationMirror> annotations, TypeMirror underlyingType) {
+  public CFValue createAbstractValue(AnnotationMirrorSet annotations, TypeMirror underlyingType) {
     return defaultCreateAbstractValue(this, annotations, underlyingType);
   }
 }
