@@ -1,11 +1,11 @@
 package org.checkerframework.checker.nullness;
 
-import java.util.Set;
-import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.type.TypeMirror;
+import org.checkerframework.checker.nullness.qual.Nullable;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.framework.flow.CFAbstractAnalysis;
 import org.checkerframework.framework.flow.CFAbstractValue;
+import org.checkerframework.javacutil.AnnotationMirrorSet;
 
 /** Boilerplate code to glue together all the parts the KeyFor dataflow classes. */
 public class KeyForAnalysis extends CFAbstractAnalysis<KeyForValue, KeyForStore, KeyForTransfer> {
@@ -31,10 +31,10 @@ public class KeyForAnalysis extends CFAbstractAnalysis<KeyForValue, KeyForStore,
   }
 
   @Override
-  public KeyForValue createAbstractValue(
-      Set<AnnotationMirror> annotations, TypeMirror underlyingType) {
+  public @Nullable KeyForValue createAbstractValue(
+      AnnotationMirrorSet annotations, TypeMirror underlyingType) {
 
-    if (!CFAbstractValue.validateSet(annotations, underlyingType, qualifierHierarchy)) {
+    if (!CFAbstractValue.validateSet(annotations, underlyingType, atypeFactory)) {
       return null;
     }
     return new KeyForValue(this, annotations, underlyingType);
