@@ -18,7 +18,6 @@ public class DisbarUseTest extends CheckerFrameworkPerDirectoryTest {
         testFiles,
         DisbarUseChecker.class,
         "disbaruse-records",
-        "-Anomsgtext",
         "-Astubs=tests/disbaruse-records",
         "-AstubWarnIfNotFound");
   }
@@ -26,7 +25,7 @@ public class DisbarUseTest extends CheckerFrameworkPerDirectoryTest {
   @Parameters
   public static String[] getTestDirs() {
     // Check for JDK 16+ without using a library:
-    if (System.getProperty("java.version").matches("^(1[6-9]|[2-9][0-9])\\..*")) {
+    if (System.getProperty("java.version").matches("^(1[6-9]|[2-9][0-9])(\\..*)?")) {
       return new String[] {"disbaruse-records"};
     } else {
       return new String[] {};
