@@ -13,7 +13,7 @@ public class FenumTest extends CheckerFrameworkPerDirectoryTest {
    * @param testFiles the files containing test code, which will be type-checked
    */
   public FenumTest(List<File> testFiles) {
-    super(testFiles, org.checkerframework.checker.fenum.FenumChecker.class, "fenum", "-Anomsgtext");
+    super(testFiles, org.checkerframework.checker.fenum.FenumChecker.class, "fenum");
   }
 
   @Parameters
