@@ -18,16 +18,17 @@ public class StubparserRecordTest extends CheckerFrameworkPerDirectoryTest {
         testFiles,
         org.checkerframework.checker.nullness.NullnessChecker.class,
         "stubparser-records",
-        "-Anomsgtext",
-        "-Astubs=tests/stubparser-records",
-        "-AstubWarnIfNotFound");
+        "-Astubs=tests/stubparser-records"
+        // Cannot use this because of JUnit 5 stub file
+        // "-AstubWarnIfNotFound",
+        );
   }
 
   @Parameterized.Parameters
   public static String[] getTestDirs() {
     // Check for JDK 16+ without using a library:
     // There is no decimal point in the JDK 17 version number.
-    if (System.getProperty("java.version").matches("^(1[6-9]|[2-9][0-9])")) {
+    if (System.getProperty("java.version").matches("^(1[6-9]|[2-9][0-9])(\\..*)?")) {
       return new String[] {"stubparser-records"};
     } else {
       return new String[] {};
