@@ -13,7 +13,7 @@ public class UnitsTest extends CheckerFrameworkPerDirectoryTest {
    * @param testFiles the files containing test code, which will be type-checked
    */
   public UnitsTest(List<File> testFiles) {
-    super(testFiles, org.checkerframework.checker.units.UnitsChecker.class, "units", "-Anomsgtext");
+    super(testFiles, org.checkerframework.checker.units.UnitsChecker.class, "units");
   }
 
   @Parameters
