@@ -3,7 +3,7 @@ package org.checkerframework.checker.test.junit.ainferrunners;
 import java.io.File;
 import java.util.List;
 import org.checkerframework.checker.testchecker.ainfer.AinferTestChecker;
-import org.checkerframework.framework.test.CheckerFrameworkPerDirectoryTest;
+import org.checkerframework.framework.test.AinferValidatePerDirectoryTest;
 import org.junit.experimental.categories.Category;
 import org.junit.runners.Parameterized.Parameters;
 
@@ -11,31 +11,24 @@ import org.junit.runners.Parameterized.Parameters;
  * Tests whole-program type inference with stub files. This test is the second pass, which ensures
  * that with the stubs in place, the errors that those annotations remove are no longer issued.
  */
-@Category(AinferTestCheckerStubsTest.class)
-public class AinferTestCheckerStubsValidationTest extends CheckerFrameworkPerDirectoryTest {
+@Category(AinferTestCheckerStubsGenerationTest.class)
+public class AinferTestCheckerStubsValidationTest extends AinferValidatePerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public AinferTestCheckerStubsValidationTest(List<File> testFiles) {
     super(
         testFiles,
         AinferTestChecker.class,
+        "testchecker",
         "ainfer-testchecker/annotated",
-        "-Anomsgtext",
-        "-Astubs=tests/ainfer-testchecker/inference-output",
+        AinferTestCheckerStubsGenerationTest.class,
+        astubsArgFromFiles(testFiles, "testchecker"),
         // "-AstubDebug",
         "-AmergeStubsWithSource",
-        "-Awarns");
-  }
-
-  @Override
-  public void run() {
-    // Only run if annotated files have been created.
-    // See ainferTest task.
-    if (!new File("tests/ainfer-testchecker/annotated/").exists()) {
-      throw new RuntimeException(
-          AinferTestCheckerStubsTest.class + " must be run before this test.");
-    }
-    super.run();
+        "-Awarns",
+        "-AskipDefs=TestPure");
   }
 
   @Parameters
