@@ -1,9 +1,10 @@
 package org.checkerframework.checker.testchecker.ainfer;
 
-import java.util.LinkedHashSet;
+import java.util.Set;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.common.basetype.BaseTypeVisitor;
 import org.checkerframework.common.value.ValueChecker;
+import org.checkerframework.framework.source.SourceChecker;
 
 /**
  * Checker for a simple type system to test whole-program inference. Uses the Value Checker as a
@@ -18,9 +19,8 @@ public class AinferTestChecker extends BaseTypeChecker {
   }
 
   @Override
-  protected LinkedHashSet<Class<? extends BaseTypeChecker>> getImmediateSubcheckerClasses() {
-    LinkedHashSet<Class<? extends BaseTypeChecker>> checkers =
-        super.getImmediateSubcheckerClasses();
+  protected Set<Class<? extends SourceChecker>> getImmediateSubcheckerClasses() {
+    Set<Class<? extends SourceChecker>> checkers = super.getImmediateSubcheckerClasses();
     checkers.add(ValueChecker.class);
     return checkers;
   }
