@@ -10,9 +10,9 @@ import org.checkerframework.framework.qual.TypeUseLocation;
 /**
  * Toy type system for testing field inference.
  *
- * @see Sibling1, Sibling2, Parent
+ * @see AinferSibling1, AinferSibling2, AinferParent
  */
-@SubtypeOf({ImplicitAnno.class})
+@SubtypeOf({AinferImplicitAnno.class})
 @Target({ElementType.TYPE_USE, ElementType.TYPE_PARAMETER})
 @TargetLocations({TypeUseLocation.EXPLICIT_LOWER_BOUND, TypeUseLocation.EXPLICIT_UPPER_BOUND})
 @DefaultFor(TypeUseLocation.LOWER_BOUND)
