@@ -1,7 +1,7 @@
 // Tests whether the stub writer correctly handles named inner classes
 // in anonymous classes.
 
-import org.checkerframework.checker.testchecker.ainfer.qual.Sibling1;
+import org.checkerframework.checker.testchecker.ainfer.qual.AinferSibling1;
 
 public class NamedInnerClassInAnonymous {
   void test() {
@@ -10,8 +10,8 @@ public class NamedInnerClassInAnonymous {
           class NamedInner {
             // The stub parser cannot parse inner classes, so stub-based WPI should
             // not attempt to print a stub file for this.
-            public int mySibling1() {
-              return ((@Sibling1 int) 0);
+            public int myAinferSibling1() {
+              return ((@AinferSibling1 int) 0);
             }
           }
         };
