@@ -174,10 +174,10 @@ public class ChapterExamples {
     // :: error: (lock.not.held)
     m.field.toString();
     // The following error is due to the fact that you cannot access "this.lock" without first
-    // having acquired "lock".  The right fix in a user scenario would be to not guard "this" with
-    // "this.lock". The current object could instead be guarded by "<self>" or by some other lock
-    // expression that is not one of its fields. We are keeping this test case here to make sure
-    // this scenario issues a warning.
+    // having acquired "lock".  The right fix in a user scenario would be to not guard "this"
+    // with "this.lock". The current object could instead be guarded by "<self>" or by some
+    // other lock expression that is not one of its fields. We are keeping this test case here
+    // to make sure this scenario issues a warning.
     // :: error: (lock.not.held)
     synchronized (lock) {
       myField = new MyClass();
@@ -265,6 +265,7 @@ public class ChapterExamples {
   @GuardedBy("lock") MyClass x = new MyClass();
 
   @GuardedBy("lock") MyClass y = x; // OK, because dereferences of y will require "lock" to be held.
+
   // :: error: (assignment)
   @GuardedBy({}) MyClass z = x; // ILLEGAL because dereferences of z do not require "lock" to be held.
 
@@ -367,10 +368,10 @@ public class ChapterExamples {
     }
     // :: error: (lock.not.held)
     p2.field = new Object();
-    // An error is issued indicating that p2 might be dereferenced without "lock" being held.  The
-    // method call need not be modified, since @GuardedBy({}) <: @GuardedByUnknown and
-    // @GuardedBy("lock") <: @GuardedByUnknown, but the lock must be acquired prior to the method
-    // call.
+    // An error is issued indicating that p2 might be dereferenced without "lock" being held.
+    // The method call need not be modified, since @GuardedBy({}) <: @GuardedByUnknown and
+    // @GuardedBy("lock") <: @GuardedByUnknown, but the lock must be acquired prior to the
+    // method call.
     // :: error: (lock.not.held)
     boolean b2 = compare(p1, p2);
   }
@@ -402,6 +403,7 @@ public class ChapterExamples {
 
   @ReleasesNoLocks
   void helper5() {}
+
   // No annotation means @ReleasesNoLocks
   void helper6() {}
 
@@ -474,7 +476,7 @@ public class ChapterExamples {
     @GuardedBy({}) int d;
     synchronized(lock) {
       // TODO re-enable this error (assignment)
-      d = b; // TODO: This should not result in assignment because 'b' is actually syntactic sugar for b.intValue().
+      d = b; // TODO: This should not result in "assignment" because 'b' is actually syntactic sugar for b.intValue().
       d = b.intValue(); // The de-sugared version does not issue an error.
     }
 
@@ -562,6 +564,7 @@ public class ChapterExamples {
   }
 
   private static final Object NULL_KEY = new Object();
+
   // A guardsatisfied.location.disallowed error is issued for the cast.
   @SuppressWarnings({"cast.unsafe", "guardsatisfied.location.disallowed"})
   private static @GuardSatisfied(1) Object maskNull(@GuardSatisfied(1) Object key) {
