@@ -3,25 +3,26 @@
 import org.checkerframework.checker.mustcall.qual.*;
 
 class BorrowOnReturn {
-  @MustCall("a") class Foo {
+  @InheritableMustCall("a")
+  class Foo {
     void a() {}
   }
 
   @Owning
   Object getOwnedFoo() {
-    // :: error: return
+    // :: error: (return)
     return new Foo();
   }
 
   Object getNoAnnoFoo() {
     // Treat as owning, so warn
-    // :: error: return
+    // :: error: (return)
     return new Foo();
   }
 
   @NotOwning
   Object getNotOwningFooWrong() {
-    // :: error: return
+    // :: error: (return)
     return new Foo();
   }
 
@@ -30,7 +31,7 @@ class BorrowOnReturn {
     f.a();
     // This is still an error for now, because it's treated as an owning pointer. TODO: fix this
     // kind of FP?
-    // :: error: return
+    // :: error: (return)
     return f;
   }
 
@@ -38,7 +39,7 @@ class BorrowOnReturn {
   Object getNotOwningFooRight() {
     Foo f = new Foo();
     f.a();
-    // :: error: return
+    // :: error: (return)
     return f;
   }
 
