@@ -2,14 +2,15 @@
 
 import org.checkerframework.checker.mustcall.qual.*;
 
-@MustCall("close") class PolyTests {
+@InheritableMustCall("close")
+class PolyTests {
   static @PolyMustCall Object id(@PolyMustCall Object obj) {
     return obj;
   }
 
   static void test1(@Owning @MustCall("close") Object o) {
     @MustCall("close") Object o1 = id(o);
-    // :: error: assignment
+    // :: error: (assignment)
     @MustCall({}) Object o2 = id(o);
   }
 
@@ -24,7 +25,7 @@ import org.checkerframework.checker.mustcall.qual.*;
 
   static void test3(@Owning @MustCall({"close"}) Object o) {
     @MustCall("close") Object o1 = new PolyTests(o);
-    // :: error: assignment
+    // :: error: (assignment)
     @MustCall({}) Object o2 = new PolyTests(o);
   }
 
@@ -35,7 +36,7 @@ import org.checkerframework.checker.mustcall.qual.*;
 
   static void testArbitary(@Owning PolyTests p) {
     @MustCall("close") Object o1 = p;
-    // :: error: assignment
+    // :: error: (assignment)
     @MustCall({}) Object o2 = p;
   }
 }
