@@ -5,9 +5,7 @@ import java.util.Comparator;
 import javax.annotation.CheckForNull;
 import javax.annotation.Nullable;
 
-// Type argument inference does not infer the correct types.
-// Once Issue 979 is fixed, this suppression should be removed.
-@SuppressWarnings({"nullness", "keyfor"}) // Issue 979
+// @skip-test 979
 public final class Issue402 {
   static final Comparator<Issue402> COMPARATOR =
       Comparator.comparing(Issue402::getStr1, Comparator.nullsFirst(Comparator.naturalOrder()))
