@@ -1,16 +1,17 @@
 // Test case for Issue 979:
 // https://github.com/typetools/checker-framework/issues/979
 
+import java.util.ArrayList;
 import java.util.List;
 
-@SuppressWarnings("nullness") // don't bother with implementations
 public class OneOf {
-  static List<String> alist;
+  static List<String> alist = new ArrayList<>();
 
   static <V> V oneof(V v1, V v2) {
     return v1;
   }
 
+  @SuppressWarnings("nullness") // don't bother with implementations
   static <T> List<T> empty() {
     return null;
   }
