@@ -7,12 +7,13 @@ import java.net.*;
 import org.checkerframework.checker.calledmethods.qual.*;
 import org.checkerframework.checker.mustcall.qual.*;
 
-@MustCall("close") class SocketContainer {
+@InheritableMustCall("close")
+class SocketContainer {
   @Owning Socket sock;
 
   public SocketContainer(String host, int port) throws Exception {
     // Assignments to owning fields should not be permitted.
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     sock = new Socket(host, port);
   }
 
@@ -20,7 +21,7 @@ import org.checkerframework.checker.mustcall.qual.*;
   public void reassign(String host, int port) throws Exception {
     sock.close();
     // For the RHS, because the field can't take ownership
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     Socket sr = new Socket(host, port);
     // No warning for overwriting the field, since it can't take ownership!
     sock = sr;
