@@ -8,7 +8,8 @@ import org.checkerframework.common.returnsreceiver.qual.*;
 
 class ACOwning {
 
-  @MustCall("a") static class Foo {
+  @InheritableMustCall("a")
+  static class Foo {
     void a() {}
   }
 
@@ -29,15 +30,15 @@ class ACOwning {
   }
 
   static void callGetNonOwningFoo() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     getNonOwningFoo();
   }
 
   static void ownershipInCallee() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     Foo f = new Foo();
     takeOwnership(f);
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     Foo g = new Foo();
     noOwnership(g);
   }
@@ -48,12 +49,12 @@ class ACOwning {
   }
 
   void owningAtReturnTest() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     Foo f = owningAtReturn();
   }
 
   void ownershipTest() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     takeOwnership(new Foo());
   }
 }
