@@ -4,6 +4,8 @@
 import java.io.IOException;
 import org.checkerframework.checker.mustcall.qual.InheritableMustCall;
 
+@SuppressWarnings(
+    "declaration.inconsistent.with.implements.clause") // stronger @InheritableMustCall
 @InheritableMustCall({"close", "foo"})
 public class CloseableAndMore implements AutoCloseable {
   void foo() {}
@@ -12,9 +14,9 @@ public class CloseableAndMore implements AutoCloseable {
   public void close() throws IOException {}
 
   public static void test_bad() {
-    // :: error: required.method.not.called
+    // :: error: (required.method.not.called)
     try (CloseableAndMore c = new CloseableAndMore()) {
-
+      // empty body
     } catch (Exception e) {
     }
   }
