@@ -8,12 +8,14 @@ class MustCallAliasLayeredStreams {
 
   public InputStream createInputStream(String filename) throws FileNotFoundException {
     if (cache == null) {
-      // The real version of this uses a mix of JDK and custom streams, so it makes more sense...
+      // The real version of this uses a mix of JDK and custom streams, so it makes more
+      // sense...
       // TODO we shouldn't report a warning here and the code is okay because the cache is
-      // non-owning,
-      // and the caller of createInputStream is the owner of all of these streams.
-      // :: error: required.method.not.called
-      cache = new DataInputStream(new BufferedInputStream(new FileInputStream(new File(filename))));
+      // non-owning, and the caller of createInputStream is the owner of all of these streams.
+      cache =
+          new DataInputStream(
+              // :: error: (required.method.not.called)
+              new BufferedInputStream(new FileInputStream(new File(filename))));
     }
     return cache;
   }
