@@ -4,13 +4,15 @@ import org.checkerframework.checker.mustcall.qual.*;
 
 public class RequiresCalledMethodsTest {
 
-  @MustCall("a") static class Foo {
+  @InheritableMustCall("a")
+  static class Foo {
     void a() {}
 
     void c() {}
   }
 
-  @MustCall("releaseFoo") static class FooField {
+  @InheritableMustCall("releaseFoo")
+  static class FooField {
     private @Owning Foo foo = null;
 
     @RequiresCalledMethods(
@@ -23,19 +25,19 @@ public class RequiresCalledMethodsTest {
 
     @CreatesMustCallFor("this")
     void overwriteFooWrong() {
-      // :: error: required.method.not.called
+      // :: error: (required.method.not.called)
       this.foo = new Foo();
     }
 
     @CreatesMustCallFor("this")
     void overwriteFooWithoutReleasing() {
-      // :: error: contracts.precondition
+      // :: error: (contracts.precondition)
       overwriteFooCorrect();
     }
 
     void releaseThenOverwriteFoo() {
       releaseFoo();
-      // :: error: reset.not.owning
+      // :: error: (reset.not.owning)
       overwriteFooCorrect();
     }
 
