@@ -18,7 +18,6 @@ public class SignatureTypeFactoryTest {
   //
   //     ArrayWithoutPackage.class,
   //     DotSeparatedIdentifiers.class,
-  //     BinaryNameWithoutPackage.class,
   //
   //     Identifier.class,
   //
@@ -104,6 +103,7 @@ public class SignatureTypeFactoryTest {
     @ClassGetSimpleName String sn;
     @FqBinaryName String fbn;
     @BinaryName String bn;
+    @Identifier String i;
     // not public, so a user can't write it.
     // @SignatureBottom String sb;
 
@@ -116,6 +116,7 @@ public class SignatureTypeFactoryTest {
     sn = s1;
     bn = s1;
     fbn = s1;
+    i = s1;
 
     us = s2;
     fqn = s2;
@@ -128,6 +129,8 @@ public class SignatureTypeFactoryTest {
     sn = s2;
     bn = s2;
     fbn = s2;
+    // :: error: (assignment)
+    i = s2;
 
     us = s3;
     fqn = s3;
@@ -140,6 +143,8 @@ public class SignatureTypeFactoryTest {
     sn = s3;
     bn = s3;
     fbn = s3;
+    // :: error: (assignment)
+    i = s3;
 
     us = s4;
     fqn = s4;
@@ -149,6 +154,7 @@ public class SignatureTypeFactoryTest {
     sn = s4;
     bn = s4;
     fbn = s4;
+    i = s4;
 
     us = s5;
     // :: error: (assignment)
@@ -163,6 +169,8 @@ public class SignatureTypeFactoryTest {
     bn = s5;
     // :: error: (assignment)
     fbn = s5;
+    // :: error: (assignment)
+    i = s5;
 
     us = s6;
     // :: error: (assignment)
@@ -178,6 +186,8 @@ public class SignatureTypeFactoryTest {
     bn = s6;
     // :: error: (assignment)
     fbn = s6;
+    // :: error: (assignment)
+    i = s6;
 
     us = s7;
     // :: error: (assignment)
@@ -193,6 +203,8 @@ public class SignatureTypeFactoryTest {
     bn = s7;
     // :: error: (assignment)
     fbn = s7;
+    // :: error: (assignment)
+    i = s7;
 
     us = s8;
     // :: error: (assignment)
@@ -209,6 +221,8 @@ public class SignatureTypeFactoryTest {
     bn = s8;
     // :: error: (assignment)
     fbn = s8;
+    // :: error: (assignment)
+    i = s8;
 
     us = s9;
     fqn = s9;
@@ -221,6 +235,8 @@ public class SignatureTypeFactoryTest {
     sn = s9;
     bn = s9;
     fbn = s9;
+    // :: error: (assignment)
+    i = s9;
 
     us = s10;
     fqn = s10;
@@ -231,6 +247,7 @@ public class SignatureTypeFactoryTest {
     sn = s10;
     bn = s10;
     fbn = s10;
+    i = s10;
 
     us = s11;
     fqn = s11;
@@ -240,6 +257,7 @@ public class SignatureTypeFactoryTest {
     sn = s11;
     bn = s11;
     fbn = s11;
+    i = s11;
 
     us = s12;
     fqn = s12;
@@ -254,6 +272,8 @@ public class SignatureTypeFactoryTest {
     // :: error: (assignment)
     bn = s12;
     fbn = s12;
+    // :: error: (assignment)
+    i = s12;
 
     us = s13;
     fqn = s13;
@@ -268,6 +288,8 @@ public class SignatureTypeFactoryTest {
     // :: error: (assignment)
     bn = s13;
     fbn = s13;
+    // :: error: (assignment)
+    i = s13;
 
     us = s14;
     // :: error: (assignment)
@@ -283,6 +305,8 @@ public class SignatureTypeFactoryTest {
     bn = s14;
     // :: error: (assignment)
     fbn = s14;
+    // :: error: (assignment)
+    i = s14;
 
     us = s15;
     // :: error: (assignment)
@@ -298,6 +322,8 @@ public class SignatureTypeFactoryTest {
     bn = s15;
     // :: error: (assignment)
     fbn = s15;
+    // :: error: (assignment)
+    i = s15;
 
     us = s16;
     // :: error: (assignment)
@@ -313,6 +339,8 @@ public class SignatureTypeFactoryTest {
     bn = s16;
     // :: error: (assignment)
     fbn = s16;
+    // :: error: (assignment)
+    i = s16;
 
     us = s17;
     // :: error: (assignment)
@@ -328,6 +356,8 @@ public class SignatureTypeFactoryTest {
     bn = s17;
     // :: error: (assignment)
     fbn = s17;
+    // :: error: (assignment)
+    i = s17;
 
     us = s18;
     // :: error: (assignment)
@@ -344,6 +374,8 @@ public class SignatureTypeFactoryTest {
     bn = s18;
     // :: error: (assignment)
     fbn = s18;
+    // :: error: (assignment)
+    i = s18;
 
     us = s19;
     // :: error: (assignment)
@@ -360,6 +392,8 @@ public class SignatureTypeFactoryTest {
     bn = s19;
     // :: error: (assignment)
     fbn = s19;
+    // :: error: (assignment)
+    i = s19;
 
     us = s20;
     fqn = s20;
@@ -372,6 +406,8 @@ public class SignatureTypeFactoryTest {
     // :: error: (assignment)
     bn = s20;
     fbn = s20;
+    // :: error: (assignment)
+    i = s20;
 
     us = s21;
     // :: error: (assignment)
@@ -388,6 +424,8 @@ public class SignatureTypeFactoryTest {
     bn = s21;
     // :: error: (assignment)
     fbn = s21;
+    // :: error: (assignment)
+    i = s21;
 
     us = s22;
     // :: error: (assignment)
@@ -404,6 +442,8 @@ public class SignatureTypeFactoryTest {
     bn = s22;
     // :: error: (assignment)
     fbn = s22;
+    // :: error: (assignment)
+    i = s22;
 
     // Examples from the manual start here
 
@@ -418,6 +458,8 @@ public class SignatureTypeFactoryTest {
     // :: error: (assignment)
     bn = t13;
     fbn = t13;
+    // :: error: (assignment)
+    i = t13;
 
     us = t14;
     fqn = t14;
@@ -439,6 +481,7 @@ public class SignatureTypeFactoryTest {
     sn = t1;
     bn = t1;
     fbn = t1;
+    i = t1;
 
     us = t12;
     // :: error: (assignment)
@@ -453,6 +496,8 @@ public class SignatureTypeFactoryTest {
     bn = t12;
     // :: error: (assignment)
     fbn = t12;
+    // :: error: (assignment)
+    i = t12;
 
     us = t5;
     fqn = t5;
@@ -463,6 +508,7 @@ public class SignatureTypeFactoryTest {
     sn = t5;
     bn = t5;
     fbn = t5;
+    i = t5;
 
     us = t2;
     // :: error: (assignment)
@@ -478,6 +524,8 @@ public class SignatureTypeFactoryTest {
     bn = t2;
     // :: error: (assignment)
     fbn = t2;
+    // :: error: (assignment)
+    i = t2;
 
     us = t6;
     fqn = t6;
@@ -491,6 +539,8 @@ public class SignatureTypeFactoryTest {
     // :: error: (assignment)
     bn = t6;
     fbn = t6;
+    // :: error: (assignment)
+    i = t6;
 
     us = t7;
     // :: error: (assignment)
@@ -505,6 +555,8 @@ public class SignatureTypeFactoryTest {
     bn = t7;
     // :: error: (assignment)
     fbn = t7;
+    // :: error: (assignment)
+    i = t7;
 
     us = t29;
     // :: error: (assignment)
@@ -520,6 +572,8 @@ public class SignatureTypeFactoryTest {
     bn = t29;
     // :: error: (assignment)
     fbn = t29;
+    // :: error: (assignment)
+    i = t29;
 
     us = t33;
     // :: error: (assignment)
@@ -535,6 +589,8 @@ public class SignatureTypeFactoryTest {
     bn = t33;
     // :: error: (assignment)
     fbn = t33;
+    // :: error: (assignment)
+    i = t33;
 
     us = t15;
     fqn = t15;
@@ -547,6 +603,8 @@ public class SignatureTypeFactoryTest {
     sn = t15;
     bn = t15;
     fbn = t15;
+    // :: error: (assignment)
+    i = t15;
 
     us = t16;
     fqn = t16;
@@ -575,6 +633,8 @@ public class SignatureTypeFactoryTest {
     bn = t22;
     // :: error: (assignment)
     fbn = t22;
+    // :: error: (assignment)
+    i = t22;
 
     us = t23;
     // :: error: (assignment)
@@ -591,6 +651,8 @@ public class SignatureTypeFactoryTest {
     bn = t23;
     // :: error: (assignment)
     fbn = t23;
+    // :: error: (assignment)
+    i = t23;
 
     us = t3;
     // :: error: (assignment)
@@ -606,6 +668,8 @@ public class SignatureTypeFactoryTest {
     bn = t3;
     // :: error: (assignment)
     fbn = t3;
+    // :: error: (assignment)
+    i = t3;
 
     us = t8;
     // :: error: (assignment)
@@ -621,6 +685,8 @@ public class SignatureTypeFactoryTest {
     bn = t8;
     // :: error: (assignment)
     fbn = t8;
+    // :: error: (assignment)
+    i = t8;
 
     us = t9;
     // :: error: (assignment)
@@ -636,6 +702,8 @@ public class SignatureTypeFactoryTest {
     bn = t9;
     // :: error: (assignment)
     fbn = t9;
+    // :: error: (assignment)
+    i = t9;
 
     us = t24;
     // :: error: (assignment)
@@ -651,6 +719,8 @@ public class SignatureTypeFactoryTest {
     bn = t24;
     // :: error: (assignment)
     fbn = t24;
+    // :: error: (assignment)
+    i = t24;
 
     us = t25;
     // :: error: (assignment)
@@ -667,6 +737,8 @@ public class SignatureTypeFactoryTest {
     bn = t25;
     // :: error: (assignment)
     fbn = t25;
+    // :: error: (assignment)
+    i = t25;
 
     us = t28;
     // :: error: (assignment)
@@ -682,6 +754,8 @@ public class SignatureTypeFactoryTest {
     bn = t28;
     // :: error: (assignment)
     fbn = t28;
+    // :: error: (assignment)
+    i = t28;
 
     us = t27;
     // :: error: (assignment)
@@ -697,6 +771,8 @@ public class SignatureTypeFactoryTest {
     bn = t27;
     // :: error: (assignment)
     fbn = t27;
+    // :: error: (assignment)
+    i = t27;
 
     us = t26;
     fqn = t26;
@@ -709,6 +785,8 @@ public class SignatureTypeFactoryTest {
     sn = t26;
     bn = t26;
     fbn = t26;
+    // :: error: (assignment)
+    i = t26;
 
     us = t32;
     // :: error: (assignment)
@@ -725,6 +803,8 @@ public class SignatureTypeFactoryTest {
     bn = t32;
     // :: error: (assignment)
     fbn = t32;
+    // :: error: (assignment)
+    i = t32;
 
     us = t30;
     fqn = t30;
@@ -753,6 +833,8 @@ public class SignatureTypeFactoryTest {
     bn = t31;
     // :: error: (assignment)
     fbn = t31;
+    // :: error: (assignment)
+    i = t31;
 
     us = t34;
     fqn = t34;
@@ -765,6 +847,8 @@ public class SignatureTypeFactoryTest {
     sn = t34;
     bn = t34;
     fbn = t34;
+    // :: error: (assignment)
+    i = t34;
 
     us = t17;
     fqn = t17;
@@ -777,6 +861,8 @@ public class SignatureTypeFactoryTest {
     sn = t17;
     bn = t17;
     fbn = t17;
+    // :: error: (assignment)
+    i = t17;
 
     us = t18;
     fqn = t18;
@@ -802,6 +888,8 @@ public class SignatureTypeFactoryTest {
     sn = t19;
     bn = t19;
     fbn = t19;
+    // :: error: (assignment)
+    i = t19;
 
     us = t21;
     fqn = t21;
@@ -831,6 +919,8 @@ public class SignatureTypeFactoryTest {
     bn = t20;
     // :: error: (assignment)
     fbn = t20;
+    // :: error: (assignment)
+    i = t20;
 
     us = t10;
     // :: error: (assignment)
@@ -846,6 +936,8 @@ public class SignatureTypeFactoryTest {
     bn = t10;
     // :: error: (assignment)
     fbn = t10;
+    // :: error: (assignment)
+    i = t10;
 
     us = t4;
     // :: error: (assignment)
@@ -861,6 +953,8 @@ public class SignatureTypeFactoryTest {
     bn = t4;
     // :: error: (assignment)
     fbn = t4;
+    // :: error: (assignment)
+    i = t4;
 
     us = t11;
     // :: error: (assignment)
@@ -876,5 +970,7 @@ public class SignatureTypeFactoryTest {
     bn = t11;
     // :: error: (assignment)
     fbn = t11;
+    // :: error: (assignment)
+    i = t11;
   }
 }
