@@ -4,7 +4,7 @@ import lib.Test;
 import org.checkerframework.framework.testchecker.variablenamedefault.quals.*;
 
 public class UseTest {
-  void testParamters(@VariableNameDefaultTop int t) {
+  void testParameters(@VariableNameDefaultTop int t) {
     Test.method(t, t);
   }
 }
