@@ -66,6 +66,7 @@ import org.checkerframework.dataflow.cfg.node.VariableDeclarationNode;
 import org.checkerframework.dataflow.cfg.node.WideningConversionNode;
 import org.checkerframework.dataflow.expression.FieldAccess;
 import org.checkerframework.dataflow.expression.JavaExpression;
+import org.checkerframework.dataflow.expression.JavaExpressionParseException;
 import org.checkerframework.dataflow.expression.LocalVariable;
 import org.checkerframework.dataflow.expression.MethodCall;
 import org.checkerframework.dataflow.qual.Pure;
@@ -73,6 +74,7 @@ import org.checkerframework.dataflow.qual.SideEffectFree;
 import org.checkerframework.dataflow.util.NodeUtils;
 import org.checkerframework.dataflow.util.PurityChecker;
 import org.checkerframework.framework.flow.CFAbstractAnalysis.FieldInitialValue;
+import org.checkerframework.framework.source.DiagMessage;
 import org.checkerframework.framework.type.AnnotatedTypeFactory;
 import org.checkerframework.framework.type.AnnotatedTypeMirror;
 import org.checkerframework.framework.type.AnnotatedTypeMirror.AnnotatedDeclaredType;
@@ -84,7 +86,6 @@ import org.checkerframework.framework.util.Contract.ConditionalPostcondition;
 import org.checkerframework.framework.util.Contract.Postcondition;
 import org.checkerframework.framework.util.Contract.Precondition;
 import org.checkerframework.framework.util.ContractsFromMethod;
-import org.checkerframework.framework.util.JavaExpressionParseUtil.JavaExpressionParseException;
 import org.checkerframework.framework.util.StringToJavaExpression;
 import org.checkerframework.javacutil.AnnotationMirrorSet;
 import org.checkerframework.javacutil.BugInCF;
@@ -137,7 +138,7 @@ public abstract class CFAbstractTransfer<
    * CFAbstractTransfer.
    *
    * @param analysis the analysis used by this transfer function
-   * @param forceConcurrentSemantics whether concurrent semantics should be forced to be on. If
+   * @param forceConcurrentSemantics true if concurrent semantics should be forced to be on. If
    *     false, concurrent semantics are turned off by default, but the user can still turn them on
    *     via {@code -AconcurrentSemantics}. If true, the user cannot turn off concurrent semantics.
    */
@@ -400,8 +401,7 @@ public abstract class CFAbstractTransfer<
   }
 
   /**
-   * Determines whether a given lambda expression may be leaked outside the method in which it
-   * appears.
+   * Returns true if a given lambda expression may be leaked outside the method in which it appears.
    *
    * <p>Currently, a lambda is considered leaked unless it is an argument to a method whose
    * corresponding formal parameter is annotated as @{@link NonLeaked}. The @{@link NonLeaked}
@@ -409,15 +409,15 @@ public abstract class CFAbstractTransfer<
    *
    * <p>For example, given the following code:
    *
-   * <pre><code>
-   *   void operateOver(Container container) {
-   *      container.forEach(item -&gt; {...});
-   *   }
+   * <pre>{@code
+   * void operateOver(Container container) {
+   *    container.forEach(item -> {...});
+   * }
    *
-   *   class Container {
-   *     void forEach(@NonLeaked Consumer&lt;T&gt;)
-   *   }
-   * </code></pre>
+   * class Container {
+   *   void forEach(@NonLeaked Consumer<T>)
+   * }
+   * }</pre>
    *
    * The lambda passed to {@code Container.forEach} is not leaked, as the parameter is annotated
    * with @{@link NonLeaked}.
@@ -910,7 +910,7 @@ public abstract class CFAbstractTransfer<
    * @param secondValue the abstract value that might be less precise
    * @param res the previous result
    * @param notEqualTo if true, indicates that the logic is flipped (i.e., the information is added
-   *     to the {@code elseStore} instead of the {@code thenStore}) for a not-equal comparison.
+   *     to the {@code elseStore} instead of the {@code thenStore}) for a not-equal comparison
    * @return the conditional transfer result (if information has been added), or {@code res}
    */
   protected TransferResult<V, S> strengthenAnnotationOfEqualTo(
@@ -1176,7 +1176,7 @@ public abstract class CFAbstractTransfer<
    * a @SuppressWarnings, then this method returns false.
    *
    * @param tree a tree
-   * @return whether to perform whole-program inference on the tree
+   * @return true if to perform whole-program inference on the tree
    */
   protected boolean shouldPerformWholeProgramInference(Tree tree) {
     TreePath path = this.analysis.atypeFactory.getPath(tree);
@@ -1189,7 +1189,7 @@ public abstract class CFAbstractTransfer<
    *
    * @param expressionTree the right-hand side of an assignment
    * @param lhsTree the left-hand side of an assignment
-   * @return whether to perform whole-program inference
+   * @return true if to perform whole-program inference
    */
   protected boolean shouldPerformWholeProgramInference(Tree expressionTree, Tree lhsTree) {
     // Check that infer is true and the tree isn't in scope of a @SuppressWarnings
@@ -1207,7 +1207,7 @@ public abstract class CFAbstractTransfer<
    *
    * @param tree a tree
    * @param elt its element
-   * @return whether to perform whole-program inference
+   * @return true if to perform whole-program inference
    */
   private boolean shouldPerformWholeProgramInference(Tree tree, Element elt) {
     return shouldPerformWholeProgramInference(tree)
@@ -1323,7 +1323,7 @@ public abstract class CFAbstractTransfer<
           System.arraycopy(e.args, 0, args, 1, e.args.length);
           analysis.checker.reportError(invocationTree, "flowexpr.parse.error.postcondition", args);
         } else {
-          analysis.checker.report(invocationTree, e.getDiagMessage());
+          analysis.checker.report(invocationTree, new DiagMessage(e));
         }
       }
     }
