@@ -9,8 +9,6 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
-import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.TypeParameterElement;
@@ -26,20 +24,24 @@ import org.checkerframework.framework.type.AnnotatedTypeMirror.AnnotatedPrimitiv
 import org.checkerframework.framework.type.AnnotatedTypeMirror.AnnotatedTypeVariable;
 import org.checkerframework.framework.type.AnnotatedTypeMirror.AnnotatedWildcardType;
 import org.checkerframework.framework.type.visitor.SimpleAnnotatedTypeVisitor;
+import org.checkerframework.javacutil.AnnotationMirrorSet;
 import org.checkerframework.javacutil.BugInCF;
 import org.checkerframework.javacutil.ElementUtils;
 import org.checkerframework.javacutil.TreeUtils;
-import org.checkerframework.javacutil.TypesUtils;
-import org.plumelib.util.CollectionsPlume;
 
 /**
  * Finds the direct supertypes of an input AnnotatedTypeMirror. See <a
- * href="https://docs.oracle.com/javase/specs/jls/se11/html/jls-4.html#jls-4.10.2">JLS section
+ * href="https://docs.oracle.com/javase/specs/jls/se17/html/jls-4.html#jls-4.10.2">JLS section
  * 4.10.2</a>.
  *
  * @see Types#directSupertypes(TypeMirror)
  */
-class SupertypeFinder {
+final class SupertypeFinder {
+
+  /** Do not instantiate. */
+  private SupertypeFinder() {
+    throw new AssertionError("Class SupertypeFinder cannot be instantiated.");
+  }
 
   // Version of method below for declared types
   /**
@@ -81,6 +83,7 @@ class SupertypeFinder {
 
     /** Types util class. */
     private final Types types;
+
     /** Annotated type factory. */
     private final AnnotatedTypeFactory atypeFactory;
 
@@ -120,7 +123,7 @@ class SupertypeFinder {
     @Override
     public List<AnnotatedTypeMirror> visitPrimitive(AnnotatedPrimitiveType type, Void p) {
       List<AnnotatedTypeMirror> superTypes = new ArrayList<>(1);
-      Set<AnnotationMirror> annotations = type.getAnnotations();
+      AnnotationMirrorSet annotations = type.getPrimaryAnnotations();
 
       // Find Boxed type
       TypeElement boxed = types.boxedClass(type.getUnderlyingType());
@@ -163,15 +166,15 @@ class SupertypeFinder {
 
     @Override
     public List<AnnotatedDeclaredType> visitDeclared(AnnotatedDeclaredType type, Void p) {
-      // Set<AnnotationMirror> annotations = type.getAnnotations();
+      // AnnotationMirrorSet annotations = type.getPrimaryAnnotations();
 
       TypeElement typeElement = (TypeElement) type.getUnderlyingType().asElement();
 
       if (type.getTypeArguments().size() != typeElement.getTypeParameters().size()) {
         if (!type.isUnderlyingTypeRaw()) {
           throw new BugInCF(
-              "AnnotatedDeclaredType's element has a different number of type parameters than"
-                  + " type.%ntype=%s%nelement=%s",
+              "AnnotatedDeclaredType's element has a different number of type"
+                  + " parameters than type.%ntype=%s%nelement=%s",
               type, typeElement);
         }
       }
@@ -182,14 +185,14 @@ class SupertypeFinder {
         supertypes.addAll(supertypesFromTree(type, classTree));
       } else {
         supertypes.addAll(supertypesFromElement(type, typeElement));
-        // final Element elem = type.getElement() == null ? typeElement : type.getElement();
+        // Element elem = type.getElement() == null ? typeElement : type.getElement();
       }
 
       if (typeElement.getKind() == ElementKind.ANNOTATION_TYPE) {
         TypeElement jlaElement =
             atypeFactory.elements.getTypeElement(Annotation.class.getCanonicalName());
         AnnotatedDeclaredType jlaAnnotation = atypeFactory.fromElement(jlaElement);
-        jlaAnnotation.addAnnotations(type.getAnnotations());
+        jlaAnnotation.addAnnotations(type.getPrimaryAnnotations());
         supertypes.add(jlaAnnotation);
       }
 
@@ -220,8 +223,8 @@ class SupertypeFinder {
     private Map<TypeVariable, AnnotatedTypeMirror> getTypeVarToTypeArg(AnnotatedDeclaredType type) {
       Map<TypeVariable, AnnotatedTypeMirror> mapping = new HashMap<>();
       // addTypeVarsFromEnclosingTypes can't be called with `type` because it calls
-      // `directSupertypes(types)`, which then calls this method. Add the type variables from `type`
-      // and then call addTypeVarsFromEnclosingTypes on the enclosing type.
+      // `directSupertypes(types)`, which then calls this method. Add the type variables from
+      // `type` and then call addTypeVarsFromEnclosingTypes on the enclosing type.
       addTypeVariablesToMapping(type, mapping);
       addTypeVarsFromEnclosingTypes(type.getEnclosingType(), mapping);
       return mapping;
@@ -271,7 +274,8 @@ class SupertypeFinder {
       // Find the super types: Start with enums and superclass
       if (typeElement.getKind() == ElementKind.ENUM) {
         supertypes.add(createEnumSuperType(type, typeElement));
-      } else if (typeElement.getSuperclass().getKind() != TypeKind.NONE) {
+      } else if (typeElement.getSuperclass().getKind() != TypeKind.NONE
+          && typeElement.getSuperclass().getKind() != TypeKind.ERROR) {
         DeclaredType superClass = (DeclaredType) typeElement.getSuperclass();
         AnnotatedDeclaredType dt =
             (AnnotatedDeclaredType) atypeFactory.toAnnotatedType(superClass, false);
@@ -282,6 +286,10 @@ class SupertypeFinder {
       }
 
       for (TypeMirror st : typeElement.getInterfaces()) {
+        if (st.getKind() == TypeKind.ERROR) {
+          // This can happen while parsing the JDK.
+          continue;
+        }
         if (type.isUnderlyingTypeRaw()) {
           st = types.erasure(st);
         }
@@ -289,8 +297,8 @@ class SupertypeFinder {
         supertypes.add(ast);
         if (type.isUnderlyingTypeRaw()) {
           if (st.getKind() == TypeKind.DECLARED) {
-            final List<? extends TypeMirror> typeArgs = ((DeclaredType) st).getTypeArguments();
-            final List<AnnotatedTypeMirror> annotatedTypeArgs = ast.getTypeArguments();
+            List<? extends TypeMirror> typeArgs = ((DeclaredType) st).getTypeArguments();
+            List<AnnotatedTypeMirror> annotatedTypeArgs = ast.getTypeArguments();
             for (int i = 0; i < typeArgs.size(); i++) {
               atypeFactory.addComputedTypeAnnotations(
                   types.asElement(typeArgs.get(i)), annotatedTypeArgs.get(i));
@@ -317,27 +325,16 @@ class SupertypeFinder {
                 atypeFactory.getAnnotatedTypeFromTypeTree(classTree.getExtendsClause());
         supertypes.add(adt);
       } else if (!ElementUtils.isObject(TreeUtils.elementFromDeclaration(classTree))) {
-        supertypes.add(AnnotatedTypeMirror.createTypeOfObject(atypeFactory));
+        if (classTree.getKind().name().contentEquals("RECORD")) {
+          supertypes.add(AnnotatedTypeMirror.createTypeOfRecord(atypeFactory));
+        } else {
+          supertypes.add(AnnotatedTypeMirror.createTypeOfObject(atypeFactory));
+        }
       }
 
       for (Tree implemented : classTree.getImplementsClause()) {
         AnnotatedDeclaredType adt =
             (AnnotatedDeclaredType) atypeFactory.getAnnotatedTypeFromTypeTree(implemented);
-        if (adt.getTypeArguments().size() != adt.getUnderlyingType().getTypeArguments().size()
-            && classTree.getSimpleName().contentEquals("")) {
-          // classTree is an anonymous class with a diamond.
-          List<AnnotatedTypeMirror> args =
-              CollectionsPlume.mapList(
-                  (TypeParameterElement element) -> {
-                    AnnotatedTypeMirror arg =
-                        AnnotatedTypeMirror.createType(element.asType(), atypeFactory, false);
-                    // TODO: After #979 is fixed, calculate the correct type
-                    // using inference.
-                    return atypeFactory.getUninferredWildcardType((AnnotatedTypeVariable) arg);
-                  },
-                  TypesUtils.getTypeElement(adt.getUnderlyingType()).getTypeParameters());
-          adt.setTypeArguments(args);
-        }
         supertypes.add(adt);
       }
 
@@ -370,15 +367,10 @@ class SupertypeFinder {
       for (AnnotatedTypeMirror t : adt.getTypeArguments()) {
         // If the type argument of super is the same as the input type
         if (atypeFactory.types.isSameType(t.getUnderlyingType(), type.getUnderlyingType())) {
-          Set<AnnotationMirror> bounds =
-              ((AnnotatedDeclaredType) atypeFactory.getAnnotatedType(dt.asElement()))
-                  .typeArgs
-                  .get(0)
-                  .getEffectiveAnnotations();
-          t.addAnnotations(bounds);
+          t.addAnnotations(type.primaryAnnotations);
         }
       }
-      adt.addAnnotations(type.getAnnotations());
+      adt.addAnnotations(type.getPrimaryAnnotations());
       return adt;
     }
 
@@ -398,17 +390,16 @@ class SupertypeFinder {
     @Override
     public List<AnnotatedTypeMirror> visitArray(AnnotatedArrayType type, Void p) {
       List<AnnotatedTypeMirror> superTypes = new ArrayList<>();
-      Set<AnnotationMirror> annotations = type.getAnnotations();
-      final AnnotatedTypeMirror objectType = atypeFactory.getAnnotatedType(Object.class);
+      AnnotationMirrorSet annotations = type.getPrimaryAnnotations();
+      AnnotatedTypeMirror objectType = atypeFactory.getAnnotatedType(Object.class);
       objectType.addAnnotations(annotations);
       superTypes.add(objectType);
 
-      final AnnotatedTypeMirror cloneableType = atypeFactory.getAnnotatedType(Cloneable.class);
+      AnnotatedTypeMirror cloneableType = atypeFactory.getAnnotatedType(Cloneable.class);
       cloneableType.addAnnotations(annotations);
       superTypes.add(cloneableType);
 
-      final AnnotatedTypeMirror serializableType =
-          atypeFactory.getAnnotatedType(Serializable.class);
+      AnnotatedTypeMirror serializableType = atypeFactory.getAnnotatedType(Serializable.class);
       serializableType.addAnnotations(annotations);
       superTypes.add(serializableType);
 
