@@ -7,13 +7,11 @@ import org.junit.runners.Parameterized.Parameters;
 
 public class AliasingTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public AliasingTest(List<File> testFiles) {
-    super(
-        testFiles,
-        org.checkerframework.common.aliasing.AliasingChecker.class,
-        "aliasing",
-        "-Anomsgtext");
+    super(testFiles, org.checkerframework.common.aliasing.AliasingChecker.class, "aliasing");
   }
 
   @Parameters
