@@ -9,14 +9,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** Tests for the compound checker design pattern. */
 public class CompoundCheckerTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public CompoundCheckerTest(List<File> testFiles) {
-    super(
-        testFiles,
-        CompoundChecker.class,
-        "compound-checker",
-        "-Anomsgtext",
-        "-AsuppressWarnings=type.checking.not.run");
+    super(testFiles, CompoundChecker.class, "compound-checker");
   }
 
   @Parameters
