@@ -9,13 +9,14 @@ import org.junit.runners.Parameterized.Parameters;
 /** Tests for the {@code -AsuggestPureMethods} command-line argument. */
 public class PuritySuggestionsTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public PuritySuggestionsTest(List<File> testFiles) {
     super(
         testFiles,
         FlowTestChecker.class,
         "flow",
-        "-Anomsgtext",
         "-AsuggestPureMethods",
         "-AcheckPurityAnnotations");
   }
