@@ -8,13 +8,14 @@ import org.junit.runners.Parameterized.Parameters;
 /** Test suite for the Subtyping Checker, using {@code @QualifierForLiterals}. */
 public class SubtypingStringPatternsFullTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public SubtypingStringPatternsFullTest(List<File> testFiles) {
     super(
         testFiles,
         org.checkerframework.common.subtyping.SubtypingChecker.class,
         "stringpatterns/stringpatterns-full",
-        "-Anomsgtext",
         "-Aquals=org.checkerframework.framework.testchecker.util.PatternUnknown,org.checkerframework.framework.testchecker.util.PatternAB,org.checkerframework.framework.testchecker.util.PatternBC,org.checkerframework.framework.testchecker.util.PatternAC,org.checkerframework.framework.testchecker.util.PatternA,org.checkerframework.framework.testchecker.util.PatternB,org.checkerframework.framework.testchecker.util.PatternC,org.checkerframework.framework.testchecker.util.PatternBottomFull");
   }
 
