@@ -15,13 +15,14 @@ import org.junit.runners.Parameterized.Parameters;
  */
 public class ValueTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public ValueTest(List<File> testFiles) {
     super(
         testFiles,
         org.checkerframework.common.value.ValueChecker.class,
         "value",
-        "-Anomsgtext",
         "-Astubs=tests/value/minints-stub.astub:tests/value/lowercase.astub",
         "-A" + ValueChecker.REPORT_EVAL_WARNS);
   }
