@@ -9,9 +9,11 @@ import org.junit.runners.Parameterized.Parameters;
 /** Create the VariableNameDefault test. */
 public class VariableNameDefaultTest extends CheckerFrameworkPerDirectoryTest {
 
-  /** @param testFiles the files containing test code, which will be type-checked */
+  /**
+   * @param testFiles the files containing test code, which will be type-checked
+   */
   public VariableNameDefaultTest(List<File> testFiles) {
-    super(testFiles, VariableNameDefaultChecker.class, "variablenamedefault", "-Anomsgtext");
+    super(testFiles, VariableNameDefaultChecker.class, "variablenamedefault");
   }
 
   @Parameters
