@@ -1,19 +1,21 @@
 package org.checkerframework.framework.testchecker.compound;
 
 import java.util.LinkedHashSet;
+import java.util.Set;
 import org.checkerframework.common.aliasing.AliasingChecker;
 import org.checkerframework.common.basetype.BaseTypeChecker;
 import org.checkerframework.common.basetype.BaseTypeVisitor;
 import org.checkerframework.common.value.ValueChecker;
+import org.checkerframework.framework.source.SourceChecker;
 
 public class AnotherCompoundChecker extends BaseTypeChecker {
   @Override
-  protected LinkedHashSet<Class<? extends BaseTypeChecker>> getImmediateSubcheckerClasses() {
+  protected Set<Class<? extends SourceChecker>> getImmediateSubcheckerClasses() {
     // Make sure that options can be accessed by sub-checkers to determine
     // which subcheckers to run.
     @SuppressWarnings("unused")
     String option = super.getOption("nomsgtext");
-    LinkedHashSet<Class<? extends BaseTypeChecker>> subcheckers = new LinkedHashSet<>();
+    LinkedHashSet<Class<? extends SourceChecker>> subcheckers = new LinkedHashSet<>();
     subcheckers.addAll(super.getImmediateSubcheckerClasses());
     subcheckers.add(AliasingChecker.class);
     subcheckers.add(ValueChecker.class);
