@@ -5,7 +5,12 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-@SuppressWarnings("unchecked")
+@SuppressWarnings({
+  "unchecked",
+  "ainfertest",
+  "value"
+}) // Don't issue warnings during ainfer tests, because more than one round of inference is required
+// for the value checker
 public class Issue1708 {
 
   static class A<T extends B> {}
