@@ -28,6 +28,9 @@ abstract class Issue1809 {
 
   interface S {}
 
+  // The Checker Framework  does not refine the type of Stream#filter based on post conditions of
+  // the passed function.
+  @SuppressWarnings({"nullness", "optional"})
   private Stream<A> xrefsFor(B b) {
     return concat(b.g().stream().flatMap(a -> a.h().stream().map(c -> f())))
         .filter(Optional::isPresent)
