@@ -6,7 +6,7 @@ import java.util.stream.Stream;
 
 interface MyList1313<E> extends Iterable<E> {}
 
-@SuppressWarnings({"all", "type.inference.not.same"}) // check for crashes
+@SuppressWarnings("all") // check for crashes
 public class Issue1313 {
   Stream<?> s;
   Iterable<?> i = s.collect(toMyList1313());
